#
# spec file for package libgdiplus
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define soname 0
Name:           libgdiplus
Version:        6.0.5
Release:        1.12
Summary:        Open Source Implementation of the GDI+ API
License:        (LGPL-2.1-or-later OR MPL-1.1) AND MIT
Group:          Development/Libraries/Mono
URL:            https://github.com/mono/libgdiplus
Source:         http://download.mono-project.com/sources/%{name}/%{name}-%{version}.tar.gz
BuildRequires:  giflib-devel
BuildRequires:  libjpeg-devel
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(cairo)
BuildRequires:  pkgconfig(fontconfig)
BuildRequires:  pkgconfig(freetype2)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(libexif)
BuildRequires:  pkgconfig(libpng)
BuildRequires:  pkgconfig(libtiff-4)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xrender)

%description
Mono library that provide a GDI+ comptible API on non-Windows
operating systems.

%package -n libgdiplus%{soname}
Summary:        Open Source Implementation of the GDI+ API
Group:          System/Libraries

%description -n libgdiplus%{soname}
Mono library that provide a GDI+ comptible API on non-Windows
operating systems.

%package devel
Summary:        Development files for libgdiplus
Group:          Development/Libraries/C and C++
Requires:       libgdiplus%{soname} = %{version}

%description devel
This library is part of the Mono project. It is required when
using System.Drawing.

%prep
%setup -q
sed -i 's/-Wall/-Wall %{optflags}/' src/Makefile.am

%build
autoreconf -fiv
%configure --disable-static
%make_build

%install
%make_install
rm %{buildroot}%{_libdir}/%{name}.la

#%check
#%make_build check

%post -n libgdiplus%{soname} -p /sbin/ldconfig
%postun -n libgdiplus%{soname} -p /sbin/ldconfig

%files -n libgdiplus%{soname}
%{_libdir}/libgdiplus.so.*
%license COPYING
%doc AUTHORS ChangeLog* NEWS README.md

%files devel
%{_libdir}/libgdiplus.so
%{_libdir}/pkgconfig/libgdiplus.pc

%changelog
* Tue Jan 12 2021 Matthias Mailänder <mailaender@opensuse.org>
- Update to version 6.0.5
- Disable the static library
* Tue Mar  3 2020 Marguerite Su <i@marguerite.su>
- Update to version 6.0.4
  * No changelog upstream.
- Drop libgdiplus-giflib5.patch, upstreamed
- Drop libgdiplus-libjpeg_prefix.patch, upstreamed
- Disable tests for now, some newly introduced tests
  didn't run at all
* Wed Mar 20 2019 Dominique Leuenberger <dimstar@opensuse.org>
- Use / as sed command delimiter. Comma can actually show up in
  optflags (think -Wl,…), which then breaks the sed command line
  parsing.
* Wed Sep  9 2015 i@marguerite.su
- rename to libgdiplus and use sub-package to provide libgdiplus0
- add patch libgdiplus-libjpeg_prefix.patch
  * fixed boo#944912: 'libjpeg_prefix' not defined in libgdiplus.pc
- build with optflags
* Sat Apr  4 2015 mailaender@opensuse.org
- Update to version 3.12
- Enable unit tests
* Sat Sep  6 2014 mailaender@opensuse.org
- Update to version 3.8
- Removed upstreamed patch libgdiplus0-libpng15.patch
- Removed upstreamed patch use-recommended-freetype-include.patch
- Use pkgconfig build dependencies where possible
- Always use system cairo
- Fixed rpmlint error: devel-file-in-non-devel-package
* Sun Aug 31 2014 jengelh@inai.de
- Update giflib patch to work with giflib7-5.1.0
* Wed Dec 11 2013 hrvoje.senjan@gmail.com
- Added use-recommended-freetype-include.patch -- Freetype upstream
  recommends using their macros together with ft2build include.
  Positive sideeffect is that this patch makes it build with both
  freetype2 2.5.1, and older version
* Mon Apr 15 2013 mmeister@suse.com
- Added url as source.
  Please see http://en.opensuse.org/SourceUrls
* Fri Mar 15 2013 cfarrell@suse.com
- license update: (LGPL-2.1+ or MPL-1.1) and MIT
  Avoid confusion
* Wed Mar 13 2013 seife+obs@b1-systems.com
- fix build with giflib-5.x (libgdiplus0-giflib5.patch)
* Sat Mar  9 2013 mailaender@opensuse.org
- update to 2.10.9
  * http://www.go-mono.com/archive/2.10.9
- add devel package
* Thu Aug 30 2012 pgajdos@suse.com
- build also against libpng15
  * libpng15.patch
* Mon Jan 16 2012 cdenicolo@suse.com
- license update: LGPL-2.1+ or MPL-1.1; MIT
* Thu Jan 12 2012 coolo@suse.com
- change license to be in spdx.org format
* Tue Feb 22 2011 ajorgensen@novell.com
- Update to 2.10
  * http://www.go-mono.com/archive/2.10
* Fri Jan  7 2011 ajorgensen@novell.com
- Update to 2.8.1
  * http://www.go-mono.com/archive/2.8.1
* Tue Oct 12 2010 ajorgensen@novell.com
- Update to 2.8
  * http://www.go-mono.com/archive/2.8
* Tue Apr 27 2010 ajorgensen@novell.com
- Update to 2.6.4
  * http://www.mono-project.com/Release_Notes_Mono_2.6.4
- Obsolete png patch
* Tue Apr 27 2010 aj@suse.de
- Fix provides/obsoletes to have a version number.
- Do not package pkgconfig file since it's not used at all.
* Sat Apr 17 2010 aj@suse.de
- Fix build with png 1.4
* Tue Mar 16 2010 ajorgensen@novell.com
- Update to 2.6.2
  * http://www.mono-project.com/Release_Notes_Mono_2.6.3
* Tue Jan 26 2010 ajorgensen@novell.com
- Update to 2.6
  * http://www.mono-project.com/Release_Notes_Mono_2.6
* Tue Aug 11 2009 ajorgensen@novell.com
- Update to 2.4.2
  * http://www.mono-project.com/Release_Notes_Mono_2.4.2
* Tue Mar 31 2009 ajorgensen@novell.com
- Update to 2.4
  * http://www.mono-project.com/Release_Notes_Mono_2.4
* Wed Sep 10 2008 ajorgensen@novell.com
- Update to 2.0 RC2
  * Compute intermediate start/end points correctly on an open
    curve.
  * Add support to compress points (skip on of two identical
    consecutive points) under some special cases.
* Fri Aug 22 2008 ajorgensen@novell.com
- Update to 2.0 (preview 2)
  * Fixes bnc#402613, lp#246376, bnc#409672, bnc#410124, bnc#413461,
    bnc#410466, bnc#410459, bnc#411454
* Tue Mar 25 2008 wberrier@suse.de
- Update to 1.9.1
  - Fix screen re-draw artifacts in winforms (bnc#388520)
  - Support for limited color displays
* Tue Mar 25 2008 wberrier@suse.de
- Update to 1.9
  - Disable internal cairo png support, since libgdiplus uses it's
  own.  Saves about 26kb of code size.
  - Fixes related to gdi+ on MacOS.
- Call ldconfig directly instead of invoking a shell.
* Mon Jan 14 2008 wberrier@suse.de
- Renamed package to libgdiplus0 to follow suse lib packaging
  standards
- Update to 1.2.6
  - Internal Cairo updated to 1.4.10
  - Special case for handling path/region excludes from infinity
  - Added GdipCloneFontFamily function
  - TextureBrush now supports transparent bitmaps
* Fri Aug  3 2007 wberrier@suse.de
- Update to 1.2.5
  - Internal Cairo updated to 1.4.6
  - header, types and enums names are now much closer to MS GDI+
  - support for 2bpp PNG and fixes for 4bpp PNG image palettes
  - support for interlaced GIF bitmaps
  - support for ColorMatrixFlag and Gray ColorMatrix in ImageAttributes
  - Implemented GdipDrawImagePointsRect[I] functions
  - Multiple printing fixes (e.g. text size/position)
- Add libexif buildrequires
* Thu Jul  5 2007 wberrier@suse.de
- Fix cairo build (new compiler?) withe ctype patch
  (http://bugs.freedesktop.org/show_bug.cgi?id=10989)
* Tue Jun  5 2007 wberrier@novell.com
- add ldconfig for post/postun
- minor spec file cleanups
- fPIC is already enabled by default, and glitz is disabled
  by default, don't bother adding options for these.
- also provides libgdiplus-devel
- update to 1.2.4
  - update internal cairo to 1.4.2, which offers better performance
  - symbols exports have been cleaned.
  This removes the possible mixup between gtk+/cairo and
  libgdiplus/cairo in newer distros
  - Initial Metafile support (emf & wmf)
* Fri Apr 13 2007 wberrier@novell.com
- add %%debug_package so debug packages get created
* Wed Mar 28 2007 wberrier@novell.com
- Adapt for suse build service
* Fri Mar  2 2007 wberrier@suse.de
- Update to 1.2.3
  - Alpha values for ColorMatrix are now correctly applied and 40%% faster
  - PNG images with alpha channel are now displayed correctly
  - New ICON format decoder (as transparent images)
  - 15/16bpp bitmaps are now supported by the BMP decoder
* Sat Dec  2 2006 wberrier@suse.de
- Update to 1.2.2 (Fate #301111)
  - upgrade internal cairo to 1.2.6
* Sat Oct 21 2006 wberrier@suse.de
- Update to 1.1.18
  - Update to cairo 1.2.4
  - fixed to pass S.D. unit tests on big endian archs
  - lots of rendering and parameter bug fixes
* Wed Aug 30 2006 wberrier@suse.de
- Update to 1.1.17
  - upgraded Cairo stack (from 1.0 to 1.2)
  - Windows.Forms: Printing is now supported.
* Mon Jul 31 2006 wberrier@suse.de
- Update to 1.1.16.1.
- update internal cairo to 1.2
- Region operations: Added GdipCombineRegionPath function to allow
  using binary operations (union, intersection, complement,
  exclude and xor) on non-rectangular regions
- Added GdipFlattenPath function (to convert curves into lines)
- Added support for region serialization (i.e. GdipGetRegionData,
  GdipGetRegionDataSize and GdipCreateRegionRgnData functions)
- Better, but still not perfect, clipping support
- TextureBrush is now working again
- Bug Fixes: 75063,76193,76907,77129,77247,77829,77976,78159,78179,
  78181,78185,78213,78237,78284,78336,78383,78478,78721,78742
* Sat Mar 25 2006 wberrier@suse.de
-Update to 1.1.13.5 (Bug fix update from trunk)
  - Avoid drawing zero length strings, fixes
  crash (77699);
  - image.c: Correct rendering of patterns (77438), cleanup all
  resources after being disposed to avoid double frees.
-Fixes without bug numbers (ongoing bug fixing of third
  party commercial components to run on Mono):
  - Gradient brush fixes.
  - font.c: Proper disposing of fonts to avoid leaks.
  - lineargradientbrush.c: fix semantics to match GDI+.
  - Memory leak fixes from running valgrind on the code.
  - Added parameter validation everywhere to avoid crashes from
  missuses: raises an error instead of a segfault.
  - pngcodec.c: Handle saving 8:8:8 files without an alpha channel.
* Wed Mar  1 2006 wberrier@suse.de
- Update to 1.1.13.4.  Fixes bugs (as well as several other updates):
  - 144798 (Novell Bugzilla) undefined C code
  - 77408
  - 77428
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Fri Jan 20 2006 wberrier@suse.de
- Update to 1.1.13.2
* Fri Jan  6 2006 wberrier@suse.de
- Update to 1.1.13
* Mon Dec 19 2005 wberrier@suse.de
- Obsolete libgdiplus-devel (since it was merged back in) (Bug #131839)
* Thu Dec 15 2005 wberrier@suse.de
- Update to 1.1.11
* Mon Nov 21 2005 wberrier@suse.de
- Cleaned up package deps and patched for new gcc4 which broke cairo
* Thu Nov 10 2005 wberrier@suse.de
- Update to 1.1.10, removed patches that made it upstream
* Fri Oct  7 2005 wberrier@suse.de
- Update to 1.1.9.2, added patch for printf statements
* Wed Sep 21 2005 wberrier@suse.de
- Remove .a, and .la from package [116295 reopened]
* Sat Sep 17 2005 wberrier@suse.de
- remove -devel package [bugzilla#116295]
* Mon Aug  1 2005 ro@suse.de
- update to 1.1.8
* Wed Apr 20 2005 ro@suse.de
- fix sentinel warnings
* Mon Feb 21 2005 clahey@suse.de
- Update to 1.1.4.
* Tue Feb  1 2005 ro@suse.de
- update to svn version for current cairo
* Tue Feb  1 2005 ro@suse.de
- use mono-devel-packages in neededforbuild
- use libgif instead of libungif
* Mon Jan 17 2005 ro@suse.de
- added c++ to neededforbuild (for libtiff)
* Tue Jan 11 2005 ro@suse.de
- update to 1.1.3
* Sun Nov 28 2004 ro@suse.de
- update to 1.1.2
* Sun Nov 28 2004 ro@suse.de
- run autoreconf to fix outdated libtool macros
* Thu Sep 16 2004 ro@suse.de
- update to 1.0.1 bugfix release
* Fri Jul  2 2004 ro@suse.de
- update to 1.0 version
* Mon Jun 21 2004 clahey@suse.de
- Updated to 0.9.
* Wed May 26 2004 ro@suse.de
- added libpng to neededforbuild
* Wed May 19 2004 clahey@suse.de
- Updated to 0.6.
* Tue Apr 20 2004 uli@suse.de
- initial package
